@@ -1,4 +1,4 @@
-//$Id: app-res.cc,v 1.8 2001/09/02 20:06:03 cactus Exp $ -*- c++ -*-
+//$Id: app-res.cc,v 1.9 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -51,54 +51,37 @@ void Resources::Application::show_ui ()
     gui->show ();
 }
 
-bool Resources::Application::load (xmlDocPtr doc,
-				   xmlNodePtr node)
+bool Resources::Application::load (StorageNode &node)
 {
-    xmlNodePtr curr_node;
-    gchar *xml_iconname = 0;
-    gchar *xml_version  = 0;
-    gchar *xml_vendor   = 0;
+    StorageNode curr_node;
 
     iconname = "";
-    version = "";
-    vendor = "";
+    version =  "";
+    vendor =   "";
     
-    for (curr_node  = node->xmlChildrenNode;
-	 curr_node != NULL;
-	 curr_node  = curr_node->next)
+    for (curr_node  = node.children ();
+	 curr_node; curr_node  = curr_node.next ())
     {
-	if (!strcmp ((char*)curr_node->name, "iconname") && !xml_iconname)
-	    xml_iconname = (gchar*)xmlNodeListGetString (doc, curr_node->xmlChildrenNode, 1);
-	else if (!strcmp ((char*)curr_node->name, "version") && !xml_version)
-	    xml_version = (gchar*)xmlNodeListGetString (doc, curr_node->xmlChildrenNode, 1);
-	else if (!strcmp ((char*)curr_node->name, "vendor") && !xml_vendor)
-	    xml_vendor = (gchar*)xmlNodeListGetString (doc, curr_node->xmlChildrenNode, 1);
+	if (curr_node.name () == "iconname")
+	    iconname = curr_node.get_content ();
+	else if (curr_node.name () == "version")
+	    version = curr_node.get_content ();
+	else if (curr_node.name () == "vendor")
+	    vendor = curr_node.get_content ();
 	else
 	    g_warning ("Error parsing `application' resource: "
-		       "unexpected element `%s'", curr_node->name);
+		       "unexpected element `%s'", curr_node.name ().c_str ());
     }
 
-    if (xml_iconname)
-    {
-	iconname = xml_iconname;
-	xmlFree (xml_iconname);
-    }
-
-    if (xml_version)
-    {
-	version = xml_version;
-	xmlFree (xml_version);
-    }
-    
     changed ();
     return true;
 }
 
-void Resources::Application::save (xmlNodePtr node) const
+void Resources::Application::save (StorageNode &node) const
 {
-    xmlNewChild (node, NULL, (xmlChar*)"iconname", (xmlChar*)string (iconname).c_str ());
-    xmlNewChild (node, NULL, (xmlChar*)"version",  (xmlChar*)string (version).c_str ());
-    xmlNewChild (node, NULL, (xmlChar*)"vendor",   (xmlChar*)string (vendor).c_str ());
+    node.add_node ("iconname", iconname);
+    node.add_node ("version",  version);
+    node.add_node ("vendor",   vendor);
 }
 
 void Resources::Application::save_rcp (ostream &ostr) const
