@@ -1,4 +1,4 @@
-//$Id: button-canvas.cc,v 1.6 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.cc,v 1.8 2001/09/19 21:13:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -39,7 +39,6 @@ void ButtonCanvasItem::update ()
 	delete group;
 
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
-    set_canvas_item (group);
     
     int width = widget->get_display_width ();
     int height = widget->get_display_height ();
@@ -68,19 +67,19 @@ void ButtonCanvasItem::update ()
 	Gnome::CanvasPoints frame_points;
 	using namespace Gnome::Art;
 	
-	frame_points.push_back (Point (x1,     y1 + 2));
-	frame_points.push_back (Point (x1 + 2, y1    ));
+	frame_points.push_back (Point (x1,     y1 + 1));
+	frame_points.push_back (Point (x1 + 2, y1 - 1 ));
 
-	frame_points.push_back (Point (x2 - 2, y1    ));
-	frame_points.push_back (Point (x2,     y1 + 2));
+	frame_points.push_back (Point (x2 - 2, y1 - 1));
+	frame_points.push_back (Point (x2,     y1 + 1));
 	
-	frame_points.push_back (Point (x2,     y2 - 2));
-	frame_points.push_back (Point (x2 - 2, y2));
+	frame_points.push_back (Point (x2,     y2 - 3));
+	frame_points.push_back (Point (x2 - 2, y2 - 1));
 	
-	frame_points.push_back (Point (x1 + 2, y2));
-	frame_points.push_back (Point (x1,     y2 - 2));
+	frame_points.push_back (Point (x1 + 2, y2 - 1));
+	frame_points.push_back (Point (x1,     y2 - 3));
 
-	frame_points.push_back (Point (x1,     y1 + 2));
+	frame_points.push_back (Point (x1,     y1 + 1));
 	
 	Gnome::CanvasPolygon *button_frame = new Gnome::CanvasPolygon (*group, frame_points);
 	button_frame->set_width_units (frame_width);
@@ -92,7 +91,7 @@ void ButtonCanvasItem::update ()
     }
 	
     int text_x = x1 + width / 2;
-    int text_y = y1 + height / 2;
+    int text_y = y1 + height / 2 - 1;
     
     draw_text (*group,
 	       widget->text, widget->font,
@@ -100,4 +99,6 @@ void ButtonCanvasItem::update ()
 	       widget->usable,
 	       GTK_ANCHOR_CENTER,
 	       width, height);
+
+    set_canvas_item (group);
 }
