@@ -1,4 +1,4 @@
-//$Id: button.cc,v 1.21 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: button.cc,v 1.22 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,21 +31,25 @@ Button::Button (Resources::Form *owner,
     Widget (owner, id),
     Resizeable (changed),
     Textual (changed, id),
+    editor (0),
     frame (changed, BUTTON_FRAME_SIMPLE),
     usable (changed, true),
     repeat (changed, false),
     anchor_right (changed, false)
 {
-    editor = new ButtonProperties (this);
 }
 
 Button::~Button ()
 {
-    delete editor;
+    if (editor)
+	delete editor;
 }
 
 Gtk::Widget *Button::create_editor ()
 {
+    if (!editor)
+	editor = new ButtonProperties (this);
+
     return editor->get_editor ();
 }
 
