@@ -1,4 +1,4 @@
-//$Id: button.h,v 1.10 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: button.h,v 1.11 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,13 +19,6 @@
 #ifndef GUIKACHU_FORM_EDITOR_BUTTON_H
 #define GUIKACHU_FORM_EDITOR_BUTTON_H
 
-#include <string>
-#include <iostream>
-#include <gnome-xml/tree.h>
-#include <sigc++/basic_signal.h>
-#include "widget.h"
-#include "resource.h"
-
 namespace Guikachu
 {
     namespace Widgets
@@ -41,6 +34,7 @@ namespace Guikachu
     }
 }
 
+#include "widget.h"
 #include "resizeable.h"
 #include "textual.h"
 
