@@ -1,4 +1,4 @@
-//$Id: canvasitem.cc,v 1.5 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: canvasitem.cc,v 1.10 2001/09/19 21:13:56 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,6 +22,7 @@
 #include <libgnome/libgnome.h>
 
 #include <gnome--/app-helper.h>
+#include <gnome--/canvas-rect.h>
 #include <libgnomeui/gnome-stock.h>
 #include <list>
 
@@ -31,7 +32,9 @@ using namespace Guikachu::GUI::FormEditor;
 
 CanvasItem::CanvasItem (Widgets::Widget  *widget_,
 			FormEditor::Form *form_):
+    item (0),
     widget (widget_),
+    bounding_box (0),
     form (form_),
     selected (false)
 {
@@ -53,21 +56,28 @@ CanvasItem::CanvasItem (Widgets::Widget  *widget_,
     
     UI::fill (popup_menu, popup_menu_list, *(popup_menu.get_accel_group ()));
 
-    widget->changed.connect (SigC::slot (this, &CanvasItem::update));
+    widget->changed.connect  (SigC::slot (this, &CanvasItem::update));
+    widget->selected.connect (SigC::slot (this, &CanvasItem::widget_selected_cb));
 }
 
-void CanvasItem::set_canvas_item (Gnome::CanvasItem *item_)
+CanvasItem::~CanvasItem ()
+{
+    if (item)
+	delete item;
+
+    if (bounding_box)
+	delete bounding_box;
+}
+
+void CanvasItem::set_canvas_item (Gnome::CanvasGroup *item_)
 {
     item = item_;
-
+    bounding_box = 0;
+    
     item->event.connect (SigC::slot (this, &CanvasItem::canvas_event_cb));
+    widget_selected_cb (selected);
 }
 
-void CanvasItem::select (bool selected_)
-{
-}
-
-
 void CanvasItem::remove_cb ()
 {
     widget->get_form ()->remove_widget (widget);
@@ -145,10 +155,10 @@ int CanvasItem::canvas_event_cb (GdkEvent *e)
 	drag_end (e);
     
 
-    // Open property editor
+    // Single click
     if ((e->type == GDK_BUTTON_PRESS) &&
 	(e->button.button == 1))
-	widget->show_editor ();
+	clicked ();
     
 
     // Context menu
@@ -219,3 +229,38 @@ void CanvasItem::drag_end (GdkEvent *e)
 	widget->y = (int)(drag_context.last_y - drag_context.offset_y);
     }
 }
+
+void CanvasItem::widget_selected_cb (bool selected_)
+{
+    selected = selected_;
+    
+    if (!selected)
+    {
+	if (bounding_box)
+	{
+	    delete bounding_box;
+	    bounding_box = 0;
+	}
+	return;
+    }
+
+    delete bounding_box;
+    bounding_box = create_bounding_box ();
+}
+
+Gnome::CanvasItem * CanvasItem::create_bounding_box ()
+{
+    double x1, x2, y1, y2;
+
+    item->get_bounds (x1, y1, x2, y2);
+
+    using namespace Gnome::CanvasHelpers;
+    Gnome::CanvasItem *bounding_box = new Gnome::CanvasRect (*item,
+							     x1 - 2, y1 - 2,
+							     x2 + 2, y2 + 2);
+    *bounding_box
+	<< width_units (2)
+	<< outline_color (GUIKACHU_SELECTED);
+
+    return bounding_box;
+}
