@@ -1,4 +1,4 @@
-//$Id: canvasitem.h,v 1.2 2001/05/14 16:54:11 cactus Exp $ -*- c++ -*-
+//$Id: canvasitem.h,v 1.5 2001/09/19 20:30:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,7 +31,7 @@ namespace Guikachu
 }
 
 #include <sigc++/basic_signal.h>
-#include <gnome--/canvas-item.h>
+#include <gnome--/canvas-group.h>
 #include <gtk--/menu.h>
 
 #include "widget.h"
@@ -44,11 +44,10 @@ namespace Guikachu
 	{
 	    class CanvasItem: public SigC::Object
 	    {
-		Gnome::CanvasItem *item;
-		Widgets::Widget   *widget;
-		Gtk::Menu          popup_menu;
-		int canvas_event_cb (GdkEvent *event);
-
+		Gnome::CanvasGroup *item;
+		Widgets::Widget    *widget;
+		Gnome::CanvasItem  *bounding_box;
+		
 		struct
 		{
 		    bool dragging;
@@ -58,20 +57,24 @@ namespace Guikachu
 		    double offset_x, offset_y;
 		} drag_context;
 	    protected:
-		FormEditor::Form *form;
+		FormEditor::Form  *form;
+		Gtk::Menu          popup_menu;
 		bool selected;
 		
 	    protected:
 		CanvasItem (Widgets::Widget  *widget,
 			    FormEditor::Form *form);
 		
-		void set_canvas_item (Gnome::CanvasItem *item);
+		void set_canvas_item (Gnome::CanvasGroup *item);
 		
 	    public:
-		virtual ~CanvasItem () {};
-		void select (bool selected);
+		virtual ~CanvasItem ();
+		SigC::Signal0<void> clicked;
 
 	    private:
+		void widget_selected_cb (bool      selected);
+		int  canvas_event_cb    (GdkEvent *event);
+
 		void remove_cb ();
 		void move_cb ();
 
@@ -80,6 +83,7 @@ namespace Guikachu
 		void drag_end    (GdkEvent *event);
 
 		virtual void update () = 0;
+		virtual Gnome::CanvasItem * create_bounding_box ();
 	    };
 	}
     }
