@@ -1,4 +1,4 @@
-//$Id: checkbox.cc,v 1.11 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: checkbox.cc,v 1.12 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,17 +31,18 @@ Checkbox::Checkbox (Resources::Form *owner,
     Widget (owner, id),
     Resizeable (changed),
     Textual (changed, id),
+    editor (0),
     usable (changed, true),
     anchor_right (changed, false),
     group (this),
     toggled (this)
 {
-    editor = new CheckboxProperties (this);
 }
 
 Checkbox::~Checkbox ()
 {
-    delete editor;
+    if (editor)
+	delete editor;
 }
 
 Checkbox::GroupProp::GroupProp (Checkbox *owner_):
@@ -118,6 +119,9 @@ void Checkbox::GroupProp::set_val (const int& value_)
 
 Gtk::Widget *Checkbox::create_editor ()
 {
+    if (!editor)
+	editor = new CheckboxProperties (this);
+    
     return editor->get_editor ();
 }
 
