@@ -1,4 +1,4 @@
-//$Id: font.cc,v 1.3 2001/07/08 17:03:11 cactus Exp $ -*- c++ -*-
+//$Id: font.cc,v 1.4 2001/09/22 18:54:11 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -66,7 +66,13 @@ void Font::parse (istream &stream)
 	curr_line_stream >> param_name;
 	curr_line_stream >> param_val;
 
-	if (param_name == "GLYPH")
+	if (param_name == "ascent")
+	    ascent = param_val;
+
+	else if (param_name == "descent")
+	    descent = param_val;
+	
+	else if (param_name == "GLYPH")
 	{
 	    in_header = false;
 	    continue;
