@@ -1,4 +1,4 @@
-//$Id: form.cc,v 1.18 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: form.cc,v 1.21 2001/09/22 19:21:42 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,7 +32,7 @@
 
 using namespace Guikachu::GUI::FormEditor;
 
-#define GUIKACHU_WINDOW_TITLE_HEIGHT 14
+#define GUIKACHU_WINDOW_TITLE_HEIGHT 13
 
 Form::Form (Resources::Form *res_,
 	    GUI::FormWindow *win_):
@@ -52,13 +52,16 @@ Form::Form (Resources::Form *res_,
     Gnome::CanvasRect *background = 
 	new Gnome::CanvasRect (*root,
 			       0, 0,
-			       GUIKACHU_SCREEN_WIDTH, GUIKACHU_SCREEN_HEIGHT);
+			       GUIKACHU_SCREEN_WIDTH - 1,
+			       GUIKACHU_SCREEN_HEIGHT - 1);
     background->set_width_pixels (0);
     background->set_fill_color (GUIKACHU_BGC);
     
     group = new Gnome::CanvasGroup (*root, 0, 0);
     group->event.connect (slot (this, &Form::canvas_event_cb));
-    
+
+    widget_group = new Gnome::CanvasGroup (*group, 0, 0);
+
     res->changed.connect (slot (this, &Form::update));
     update ();
 }
@@ -80,12 +83,16 @@ void Form::update ()
     group->set_x (res->x);
     group->set_y (res->y);
 
+    widget_group->raise_to_top ();
+    
+#if 0
     /* Reset canvas group */
     if (widget_group)
 	delete widget_group;
     widget_group = new Gnome::CanvasGroup (*group, 0, 0);
 
-    /* This looks like my ass
+#if 0
+    /* FIXME: This looks like my ass
      * But I can't really find a feasible solution to bind the
      * lifetime of Guikachu::GUI::FormEditor::CanvasItems to
      * the lifetime of their underlying Gnome::CanvasItem.
@@ -100,9 +107,14 @@ void Form::update ()
     for (set<Widgets::Widget*>::iterator i = wset.begin ();
 	 i != wset.end (); i++)
     {
+	using namespace SigC;
+	
 	CanvasItem *canvas_item = (*i)->get_canvas_item (this);
+	canvas_item->clicked.connect (bind (slot (this, &Form::widget_clicked_cb), *i));
 	canvas_item_list.push_back (canvas_item);
     }
+#endif
+#endif
 }
 
 Gtk::Widget* Form::get_editor ()
@@ -214,10 +226,10 @@ void Form::draw_title_nonmodal ()
 {
     Gnome::CanvasPoints points;
     double title_width;
-    Font &font = get_title_font ();
+    const Font &font = get_title_font ();
     
-    title_width = get_string_width (1, res->title) + 2; /* Title is font#1 (FIXME) */
-    title_width = MIN (title_width + 5, res->width);
+    title_width = get_string_width (1, res->title); /* Title is font#1 (FIXME) */
+    title_width = MIN (title_width + 4, res->width);
 
     int max_width = res->width;
     int max_height = MIN (res->height, GUIKACHU_WINDOW_TITLE_HEIGHT);
@@ -246,13 +258,13 @@ void Form::draw_title_nonmodal ()
 
 	render_text (*title_group, res->title, font,
 		     Gdk_Color (GUIKACHU_BGC),
-		     2, 2,
+		     3, 2,
 		     GTK_ANCHOR_NW,
 		     max_width, max_height);
 	
 	*(new Gnome::CanvasRect (*title_group))
 	    << x1 (0) << y1 (GUIKACHU_WINDOW_TITLE_HEIGHT)
-	    << x2 (res->width) << y2 (GUIKACHU_WINDOW_TITLE_HEIGHT + 1)
+	    << x2 (res->width - 1) << y2 (GUIKACHU_WINDOW_TITLE_HEIGHT + 1)
 	    << width_units (1)
 	    << fill_color (GUIKACHU_FGC);
     }
@@ -261,7 +273,7 @@ void Form::draw_title_nonmodal ()
 void Form::draw_title_modal ()
 {
     Gnome::CanvasPoints points;
-    Font &font = get_title_font ();
+    const Font &font = get_title_font ();
     
     int title_center = res->width / 2;
     int title_height = MIN (res->height, 11);
@@ -349,7 +361,7 @@ int Form::canvas_event_cb (GdkEvent *e)
 	group->grab (GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
 		     cursor, e->button.time);
 	
-	show_editor ();
+	clicked ();
     }
     
     return true;
