@@ -1,4 +1,4 @@
-//$Id: graffiti.cc,v 1.7 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: graffiti.cc,v 1.8 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,18 +26,22 @@ using namespace Guikachu::GUI::FormEditor;
 
 Graffiti::Graffiti (Resources::Form *owner,
 		    const string& id):
-    Widget (owner, id)
+    Widget (owner, id),
+    editor (0)
 {
-    editor = new GraffitiProperties (this);
 }
 
 Graffiti::~Graffiti ()
 {
-    delete editor;
+    if (editor)
+	delete editor;
 }
 
 Gtk::Widget *Graffiti::create_editor ()
 {
+    if (!editor)
+	editor = new GraffitiProperties (this);
+    
     return editor->get_editor ();
 }
 
