@@ -1,4 +1,4 @@
-//$Id: label-prop.cc,v 1.12 2001/07/24 01:48:19 cactus Exp $ -*- c++ -*-
+//$Id: label-prop.cc,v 1.16 2001/09/01 13:10:16 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -21,9 +21,9 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
-#include "widgets/entry.h"
-#include "widgets/num-entry.h"
-#include "widgets/pos-entry.h"
+#include "widget-prop.h"
+#include "textual-prop.h"
+
 #include "widgets/togglebutton.h"
 #include "widgets/propertytable.h"
 
@@ -37,57 +37,21 @@ LabelProperties::LabelProperties (Widgets::Label *res)
     Gtk::Widget *control;
     
     /* Resource ID */
-    control = new GUI::Entry (
-	false,
-	slot (res, &Widgets::Label::get_id),
-	slot (res, &Widgets::Label::set_id),
-	res->changed);
-    proptable->add (_("Resource ID:"), *manage (control));
+    WidgetProperties::add_general_controls (res, *proptable);
 
     /* Text */
-    control = new GUI::Entry (
-	true,
-	slot (res, &Widgets::Label::get_text),
-	slot (res, &Widgets::Label::set_text),
-	res->changed);
-    proptable->add (_("Text:"), *manage (control));
-    
-    /* Font */
-    control = new GUI::NumEntry (
-	0, 2,
-	slot (res, &Widgets::Label::get_font),
-	slot (res, &Widgets::Label::set_font),
-	res->changed);
-    proptable->add (_("Font:"), *manage (control));
+    TextualProperties::add_controls (res, *proptable);
     
     /* Usable */
-    control = new GUI::ToggleButton (
-	slot (res, &Widgets::Label::get_usable),
-	slot (res, &Widgets::Label::set_usable),
-	res->changed);
-    proptable->add (_("Usable:"), *manage (control),
+    control = new GUI::ToggleButton (res->usable);
+    proptable->add (_("_Usable:"), *manage (control),
 		    _("Non-usable widgets are not rendered by default"));
 
     /* Separator */
     proptable->add_separator ();
 
-    /* X */
-    control = new GUI::PosEntry (
-	slot (res, &Widgets::Label::get_x),
-	slot (res, &Widgets::Label::set_x),
-	res->changed);
-    proptable->add (_("X:"), *manage (control),
-		    _("Horizontal position of the widget, relative "
-		      "to the parent form"));
-
-    /* Y */
-    control = new GUI::PosEntry (
-	slot (res, &Widgets::Label::get_y),
-	slot (res, &Widgets::Label::set_y),
-	res->changed);
-    proptable->add (_("Y:"), *manage (control),
-		    _("Vertical position of the widget, relative "
-		      "to the parent form"));
+    /* Position */
+    WidgetProperties::add_position_controls (res, *proptable);
     
     proptable->show ();
     property_editor = manage (proptable);
@@ -96,7 +60,7 @@ LabelProperties::LabelProperties (Widgets::Label *res)
 
 LabelProperties::~LabelProperties ()
 {
-    property_editor->destroy ();
+    delete property_editor;
 }
 
 Gtk::Widget* LabelProperties::get_editor ()
