@@ -1,4 +1,4 @@
-//$Id: list-canvas.cc,v 1.10 2001/09/22 19:07:54 cactus Exp $ -*- c++ -*-
+//$Id: list-canvas.cc,v 1.11 2001/10/09 16:37:13 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -48,7 +48,7 @@ void ListCanvasItem::update ()
     bool usable = widget->usable;
 
     /* Render text items */
-    vector<string> listitems = widget->items;
+    const vector<string> &listitems = widget->items;
 
     // FIXME: size() is unsigned, visible_items is signed
     int num_items = listitems.size ();
