@@ -1,4 +1,4 @@
-//$Id: list-prop.cc,v 1.3 2001/07/05 18:07:05 cactus Exp $ -*- c++ -*-
+//$Id: list-prop.cc,v 1.6 2001/09/01 13:10:16 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,6 +32,8 @@
 
 #include <gtk--/notebook.h>
 
+#include "widget-prop.h"
+
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
 
@@ -45,71 +47,33 @@ ListProperties::ListProperties (List *res)
     /* Page 1: General properties */
     GUI::PropertyTable *proptable = new GUI::PropertyTable ();
     Gtk::Widget *control;
-    
+
     /* Resource ID */
-    control = new GUI::Entry (
-	false,
-	slot (res, &Widgets::List::get_id),
-	slot (res, &Widgets::List::set_id),
-	res->changed);
-    proptable->add (_("Resource ID:"), *manage (control));
+    WidgetProperties::add_general_controls (res, *proptable);
 
     /* Font */
-    control = new GUI::NumEntry (
-	0, 2,
-	slot (res, &Widgets::List::get_font),
-	slot (res, &Widgets::List::set_font),
-	res->changed);
-    proptable->add (_("Font:"), *manage (control));
+    control = new GUI::NumEntry (0, 2, res->font);
+    proptable->add (_("_Font:"), *manage (control));
 
     /* Number of visible items */
-    control = new GUI::NumEntry (
-	1, 20,
-	slot (res, &Widgets::List::get_visible_items),
-	slot (res, &Widgets::List::set_visible_items),
-	res->changed);
-    proptable->add (_("Visible items:"), *manage (control));
+    control = new GUI::NumEntry (1, 20, res->visible_items);
+    proptable->add (_("_Visible items:"), *manage (control));
 
     /* Usable */
-    control = new GUI::ToggleButton (
-	slot (res, &Widgets::List::get_usable),
-	slot (res, &Widgets::List::set_usable),
-	res->changed);
-    proptable->add (_("Usable:"), *manage (control),
+    control = new GUI::ToggleButton (res->usable);
+    proptable->add (_("_Usable:"), *manage (control),
 		    _("Non-usable widgets are not rendered by default"));
 
     /* Separator */
     proptable->add_separator ();
 
-    /* X */
-    control = new GUI::PosEntry (
-	slot (res, &Widgets::List::get_x),
-	slot (res, &Widgets::List::set_x),
-	res->changed);
-    proptable->add (_("X:"), *manage (control),
-		    _("Horizontal position of the widget, relative "
-		      "to the parent form"));
-
-    /* Y */
-    control = new GUI::PosEntry (
-	slot (res, &Widgets::List::get_y),
-	slot (res, &Widgets::List::set_y),
-	res->changed);
-    proptable->add (_("Y:"), *manage (control),
-		    _("Vertical position of the widget, relative "
-		      "to the parent form"));
+    /* Position */
+    WidgetProperties::add_position_controls (res, *proptable);
 
     /* Width */
-    control = new GUI::PosEntry (
-	slot (res, &Widgets::List::get_width),
-	slot (res, &Widgets::List::set_width),
-	res->changed);
-    control = new GUI::AutoToggle (
-	*manage (control),
-	slot (res, &Widgets::List::get_manual_width),
-	slot (res, &Widgets::List::set_manual_width),
-	res->changed);
-    proptable->add (_("Width:"), *manage (control),
+    control = new GUI::PosEntry (res->width);
+    control = new GUI::AutoToggle (*manage (control), res->manual_width);
+    proptable->add (_("_Width:"), *manage (control),
 		    _("Horizontal size of the widget "
 		      "(check to set manually)"));
 
@@ -122,10 +86,7 @@ ListProperties::ListProperties (List *res)
     Gtk::Table *table = new Gtk::Table ();
     table->set_border_width (5);
     
-    control = new GUI::StringList (
-	slot (res, &Widgets::List::get_items),
-	slot (res, &Widgets::List::set_items),
-	res->changed);
+    control = new GUI::StringList (res->items);
     table->add (*manage (control));
     
     notebook->pages ().push_back (
@@ -140,7 +101,7 @@ ListProperties::ListProperties (List *res)
 
 ListProperties::~ListProperties ()
 {
-    property_editor->destroy ();
+    delete property_editor;
 }
 
 Gtk::Widget* ListProperties::get_editor ()
