@@ -1,4 +1,4 @@
-//$Id: list.h,v 1.6 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: list.h,v 1.7 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,14 +19,6 @@
 #ifndef GUIKACHU_FORM_EDITOR_LIST_H
 #define GUIKACHU_FORM_EDITOR_LIST_H
 
-#include <string>
-#include <iostream>
-#include <gnome-xml/tree.h>
-#include <sigc++/basic_signal.h>
-
-#include "widget.h"
-#include "resource.h"
-
 namespace Guikachu
 {
     namespace Widgets
@@ -35,6 +27,8 @@ namespace Guikachu
     }
 }
 
+#include "widget.h"
+
 #include "list-prop.h"
 
 #include <vector>
