@@ -1,4 +1,4 @@
-//$Id: palette.cc,v 1.8 2001/09/22 19:21:42 cactus Exp $ -*- c++ -*-
+//$Id: palette.cc,v 1.9 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -101,6 +101,10 @@ Palette::Palette ():
     PALETTE_ADD_BUTTON(Widgets::WIDGET_SCROLLBAR,
 		       _("Vertical scroll bar"),
 		       0, 3);
+
+    PALETTE_ADD_BUTTON(Widgets::WIDGET_TABLE,
+		       _("Multi-column table"),
+		       1, 3);
 		       
 #undef PALETTE_ADD_BUTTON
 
