@@ -1,4 +1,4 @@
-//$Id: popup-trigger.cc,v 1.8 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.cc,v 1.9 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,20 +31,24 @@ PopupTrigger::PopupTrigger (Resources::Form *owner,
     Widget (owner, id),
     Resizeable (changed),
     Textual (changed, id),
+    editor (0),
     list_id (changed, ""),
     usable (changed, true),
     anchor_right (changed, false)
 {
-    editor = new PopupTriggerProperties (this);
 }
 
 PopupTrigger::~PopupTrigger ()
 {
-    delete editor;
+    if (editor)
+	delete editor;
 }
 
 Gtk::Widget *PopupTrigger::create_editor ()
 {
+    if (!editor)
+	editor = new PopupTriggerProperties (this);
+    
     return editor->get_editor ();
 }
 
