@@ -1,4 +1,4 @@
-//$Id: pushbutton.cc,v 1.10 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton.cc,v 1.11 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,19 +31,23 @@ PushButton::PushButton (Resources::Form *owner,
     Widget (owner, id),
     Resizeable (changed),
     Textual (changed, id),
+    editor (0),
     usable (changed, true),
     group (changed)
 {
-    editor = new PushButtonProperties (this);
 }
 
 PushButton::~PushButton ()
 {
-    delete editor;
+    if (editor)
+	delete editor;
 }
 
 Gtk::Widget *PushButton::create_editor ()
 {
+    if (!editor)
+	editor = new PushButtonProperties (this);
+    
     return editor->get_editor ();
 }
 
