@@ -1,4 +1,4 @@
-//$Id: scrollbar.cc,v 1.7 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.cc,v 1.9 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,22 +30,48 @@ ScrollBar::ScrollBar (Resources::Form *owner,
 		      const string& id):
     Widget (owner, id),
     Resizeable (changed),
+    editor (0),
     usable (changed, true),
     min_value (changed, 0),
     max_value (changed, 0),
     value (changed, 0),
     page_size (changed, 0)
 {
-    editor = new ScrollBarProperties (this);
+    changed.connect (SigC::slot (this, &ScrollBar::update));
 }
 
 ScrollBar::~ScrollBar ()
 {
-    delete editor;
+    if (editor)
+	delete editor;
+}
+
+void ScrollBar::update ()
+{
+    static bool update_block = false;
+
+    if (update_block)
+	return;
+
+    update_block = true;
+    
+    if (max_value < min_value)
+	max_value = min_value;
+
+    if (value < min_value)
+	value = min_value;
+
+    if (value > max_value)
+	value = max_value;
+
+    update_block = false;
 }
 
 Gtk::Widget* ScrollBar::create_editor ()
 {
+    if (!editor)
+	editor = new ScrollBarProperties (this);
+
     return editor->get_editor ();
 }
 
@@ -58,7 +84,7 @@ bool ScrollBar::load (StorageNode &node)
 {
     /* Non-NULL default values */
     usable = false;
-
+    
     for (StorageNode curr_node  = node.children ();
 	 curr_node; curr_node++)
     {
@@ -101,7 +127,7 @@ bool ScrollBar::load (StorageNode &node)
 		       "unexpected element `%s'",
 		       curr_node.name ().c_str ());
 	}
-
+    
     changed ();
 
     return true;
