@@ -1,4 +1,4 @@
-//$Id: scrollbar.h,v 1.4 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: scrollbar.h,v 1.6 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,13 +19,6 @@
 #ifndef GUIKACHU_FORM_EDITOR_SCROLLBAR_H
 #define GUIKACHU_FORM_EDITOR_SCROLLBAR_H
 
-#include <string>
-#include <iostream>
-#include <gnome-xml/tree.h>
-#include <sigc++/basic_signal.h>
-#include "widget.h"
-#include "resource.h"
-
 namespace Guikachu
 {
     namespace Widgets
@@ -34,6 +27,7 @@ namespace Guikachu
     }
 }
 
+#include "widget.h"
 #include "resizeable.h"
 
 #include "scrollbar-prop.h"
@@ -67,6 +61,9 @@ namespace Guikachu
 	    virtual bool load (StorageNode &node);
 	    virtual void save (StorageNode &node) const;
 	    virtual void save_rcp (ostream &ostr) const;
+
+	private:
+	    void update ();
 	};
     }
 }
