@@ -1,4 +1,4 @@
-//$Id: selector-trigger.cc,v 1.9 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.cc,v 1.10 2001/10/07 13:06:19 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,19 +31,23 @@ SelectorTrigger::SelectorTrigger (Resources::Form *owner,
     Widget (owner, id),
     Resizeable (changed),
     Textual (changed, id),
+    editor (0),
     usable (changed, true),
     anchor_right (changed, false)
 {
-    editor = new SelectorTriggerProperties (this);
 }
 
 SelectorTrigger::~SelectorTrigger ()
 {
-    delete editor;
+    if (editor)
+	delete editor;
 }
 
 Gtk::Widget* SelectorTrigger::create_editor ()
 {
+    if (!editor)
+	editor = new SelectorTriggerProperties (this);
+    
     return editor->get_editor ();
 }
 
