@@ -1,4 +1,4 @@
-//$Id: selector-trigger.h,v 1.6 2001/09/18 22:28:47 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.h,v 1.7 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,10 +19,6 @@
 #ifndef GUIKACHU_FORM_EDITOR_SELECTOR_TRIGGER_H
 #define GUIKACHU_FORM_EDITOR_SELECTOR_TRIGGER_H
 
-#include <string>
-#include <iostream>
-#include <gnome-xml/tree.h>
-
 namespace Guikachu
 {
     namespace Widgets
