@@ -1,4 +1,4 @@
-//$Id: widget-util.cc,v 1.3 2001/09/22 19:21:43 cactus Exp $ -*- c++ -*-
+//$Id: widget-util.cc,v 1.4 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,6 +32,7 @@ namespace {
 #include "pixmaps/popup-trigger.xpm"
 #include "pixmaps/scrollbar.xpm"
 #include "pixmaps/text-field.xpm"
+#include "pixmaps/table.xpm"
 }
 
 string Widgets::type_id_from_type (Widgets::Type type)
@@ -72,6 +73,9 @@ string Widgets::type_id_from_type (Widgets::Type type)
     case Widgets::WIDGET_TEXT_FIELD:
 	type_id = "text_field";
 	break;
+    case Widgets::WIDGET_TABLE:
+	type_id = "table";
+	break;
     case Widgets::WIDGET_NONE:
 	g_assert_not_reached ();
 	break;
@@ -106,6 +110,8 @@ Widgets::Type Widgets::type_from_type_id (const string &type_id)
 	type = Widgets::WIDGET_SCROLLBAR;
     else if (type_id == "text_field")
 	type = Widgets::WIDGET_TEXT_FIELD;
+    else if (type_id == "table")
+	type = Widgets::WIDGET_TABLE;
     else
 	type = Widgets::WIDGET_NONE;
     
@@ -138,6 +144,8 @@ const char * const * Widgets::type_icon (Widgets::Type type)
 	return selector_trigger_xpm;
     case Widgets::WIDGET_TEXT_FIELD:
 	return text_field_xpm;
+    case Widgets::WIDGET_TABLE:
+	return table_xpm;
     case Widgets::WIDGET_NONE:
 	g_assert_not_reached ();
     }
