@@ -1,4 +1,4 @@
-//$Id: widget.h,v 1.24 2001/09/22 17:59:13 cactus Exp $ -*- c++ -*-
+//$Id: widget.h,v 1.25 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -35,7 +35,8 @@ namespace Guikachu
 	    WIDGET_LIST,
 	    WIDGET_POPUP_TRIGGER,
 	    WIDGET_SCROLLBAR,
-	    WIDGET_TEXT_FIELD
+	    WIDGET_TEXT_FIELD,
+	    WIDGET_TABLE
 	};
 
 	class Widget;
