@@ -1,4 +1,4 @@
-//$Id: form-res.cc,v 1.21 2001/09/22 19:21:42 cactus Exp $ -*- c++ -*-
+//$Id: form-res.cc,v 1.22 2001/10/02 21:47:04 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -31,6 +31,7 @@
 #include "form-editor/popup-trigger.h"
 #include "form-editor/scrollbar.h"
 #include "form-editor/text-field.h"
+#include "form-editor/table.h"
 
 using namespace Guikachu::Resources;
 using namespace Guikachu;
@@ -118,6 +119,9 @@ Widgets::Widget* Form::create_widget (Widgets::Type  type,
     case Widgets::WIDGET_TEXT_FIELD:
 	widget = new Widgets::TextField (this, id);
 	break;
+    case Widgets::WIDGET_TABLE:
+	widget = new Widgets::Table (this, id);
+	break;
     case Widgets::WIDGET_NONE:
 	g_assert_not_reached ();
 	return 0;
