@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.26 2001/08/31 16:11:37 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.29 2001/09/19 20:30:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -47,6 +47,7 @@ static Guikachu::GUI::Palette *palette = 0;
 FormWindow::FormWindow (Form *res_):
     res (res_),
     edited_widget (0),
+    selected_widget (0),
     canvas_overlay (0),
     selected_widget_type (Widgets::WIDGET_NONE)
 {
@@ -65,15 +66,16 @@ FormWindow::FormWindow (Form *res_):
     
     canvas = wrap (GNOME_CANVAS (glade_xml_get_widget (gui, "form_canvas")));
     Gtk::Tree *tree = wrap (GTK_TREE (glade_xml_get_widget (gui, "form_tree")));
+    tree->map_ (); // FIXME: Is this evil?
     
     FormWindow_Helpers::TopTreeItem *item = new FormWindow_Helpers::TopTreeItem (res);
     item->show ();
-    item->activate.connect (slot (this, &FormWindow::toplevel_tree_cb));
+    item->activate.connect (slot (this, &FormWindow::form_clicked_cb));
     tree->add (*manage (item));
     top_treeitem = item;
     
     form = new FormEditor::Form (res, this);
-    form->show_editor.connect (slot (this, &FormWindow::toplevel_prev_cb));
+    form->clicked.connect (slot (this, &FormWindow::form_clicked_cb));
     
     // Initial widget tree
     const set<Widgets::Widget*>& widgets = res->get_widgets ();
@@ -111,9 +113,9 @@ void FormWindow::show ()
     palette->get_window ().raise ();
     
     if (edited_widget)
-	edited_widget->show_editor ();
+	show_property_editor (edited_widget);
     else
-	form->show_editor ();
+	show_form_property_editor ();
 }
 
 int FormWindow::delete_event_impl (GdkEventAny *e)
@@ -159,8 +161,8 @@ void FormWindow::widget_created_cb (Widgets::Widget *widget)
 
     using namespace SigC;
     
-    widget->show_editor.connect (bind (
-	slot (this, &FormWindow::widget_activate_prev_cb),
+    widget->request_edit.connect (bind (
+	slot (this, &FormWindow::show_property_editor),
 	widget));
     
     // Add tree item
@@ -171,20 +173,27 @@ void FormWindow::widget_created_cb (Widgets::Widget *widget)
 	top_treeitem->set_subtree (*manage (tree));
 	top_treeitem->expand ();
     }
+
+    // Add canvas item
+    FormEditor::CanvasItem *canvas_item = widget->get_canvas_item (form);
+    canvas_item->clicked.connect (bind (slot (this, &FormWindow::widget_clicked_cb), widget));
     
     FormWindow_Helpers::WidgetTreeItem *item = new FormWindow_Helpers::WidgetTreeItem (widget);
     item->show ();
-    item->activate.connect (bind (
-	slot (this, &FormWindow::widget_activate_tree_cb),
-	widget));
+    // FIXME: clearly the selection stuff needs clearer
+    // model/view/controller separation
+    item->activate.connect (bind (slot (this, &FormWindow::widget_clicked_cb), widget));
     
-    tree->add (*manage (item));
+    tree->add (*item);
 }
 
 void FormWindow::widget_removed_cb (Widgets::Widget *widget)
-{    
+{
+    if (widget == selected_widget)
+	selected_widget = 0;
+    
     if (widget == edited_widget)
-	toplevel_prev_cb ();
+	form_clicked_cb ();
     
     // Remove tree item
     Gtk::Tree::ItemList &itemlist = top_treeitem->get_subtree ()->tree ();
@@ -310,42 +319,28 @@ void FormWindow::show_form_property_editor ()
     property_window->get_window ().raise ();
 }
 
-void FormWindow::toplevel_prev_cb ()
+void FormWindow::form_clicked_cb ()
 {
-    /*
-    top_treeitem->select ();
-    */
-    
-    show_form_property_editor ();
-}
-
-void FormWindow::toplevel_tree_cb ()
-{
-    show_form_property_editor ();
-}
-
-void FormWindow::widget_activate_prev_cb (Widgets::Widget *widget)
-{
-#if 0
-    /* Make the appropriate tree item selected */
-    Gtk::Tree *tree = top_treeitem->get_subtree ();
-    Gtk::Tree::ItemList itemlist = tree->tree ();
-
-    int row = 0;
-    for (Gtk::Tree::ItemList::iterator i = itemlist.begin ();
-	 i != itemlist.end (); i++, row++)
+    if (selected_widget)
     {
-	Widgets::Widget *curr_widget = static_cast <Widgets::Widget*>
-	    ((*i)->get_user_data ());
-	if (curr_widget == widget)
-	    tree->select_item (row);
+	selected_widget->selected (false);
+	selected_widget = 0;
     }
-#endif
-    
-    show_property_editor (widget);
+
+    top_treeitem->select ();
+   
+    show_form_property_editor ();
 }
 
-void FormWindow::widget_activate_tree_cb (Widgets::Widget *widget)
+void FormWindow::widget_clicked_cb (Widgets::Widget *widget)
 {
-    show_property_editor (widget);
+    if (selected_widget)
+	selected_widget->selected (false);
+    else
+	top_treeitem->deselect ();
+    
+    widget->selected (true);
+    selected_widget = widget;
+
+    widget->request_edit ();
 }
