@@ -1,4 +1,4 @@
-//$Id: property.cc,v 1.1 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: property.cc,v 1.2 2001/10/10 16:17:45 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,6 +30,17 @@ ID::ID (notify_signal_t &notify_signal,
 
 void ID::set_val (const string& value_)
 {
-    if (ResourceManager::rename_resource (value, value_))
-	Property<string>::set_val (value_);
+    string real_id = value_;
+
+    for (string::iterator i = real_id.begin ();
+	 i != real_id.end (); i++)
+    {
+	if (*i == ' ')
+	    *i = '_';
+    }
+
+    cerr << "renaming to " << real_id << endl;
+    
+    if (ResourceManager::rename_resource (value, real_id))
+	Property<string>::set_val (real_id);
 }
