@@ -1,4 +1,4 @@
-//$Id: property.h,v 1.3 2001/09/14 13:02:01 cactus Exp $ -*- c++ -*-
+//$Id: property.h,v 1.5 2001/10/09 16:37:12 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -51,7 +51,7 @@ namespace Guikachu
 	    
 	virtual ~Property () {};
 
-	virtual inline value_t get_val () const { return value; };
+	virtual inline const value_t & get_val () const { return value; };
 	virtual void set_val (const value_t &value_)
 	    {
 		if (value != value_)
@@ -62,6 +62,7 @@ namespace Guikachu
 	    };
 	
 	inline const value_t& operator= (const value_t &value_) { set_val (value_); return value; };
+	inline const value_t& operator= (const self_t  &other)  { set_val (other.value); return value; };
 	inline operator value_t () const { return get_val (); };
 	inline value_t operator() () const { return get_val (); };
 
