@@ -1,4 +1,4 @@
-//$Id: resource-manager.cc,v 1.9 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.10 2001/10/10 16:17:45 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -88,28 +88,36 @@ Resources::Resource* ResourceManager::create_resource (Resources::Type type,
 {
     if (!register_id (id))
 	return 0;
-	
+
+    string real_id = id;
+    for (string::iterator i = real_id.begin ();
+	 i != real_id.end (); i++)
+    {
+	if (*i == ' ')
+	    *i = '_';
+    }
+    
     Resources::Resource *res;
 
     switch (type)
     {
     case Resources::RESOURCE_DIALOG:
-	res = new Resources::Dialog (id);
+	res = new Resources::Dialog (real_id);
 	break;
     case Resources::RESOURCE_STRING:
-	res = new Resources::String (id);
+	res = new Resources::String (real_id);
 	break;
     case Resources::RESOURCE_MENU:
-	res = new Resources::Menu (id);
+	res = new Resources::Menu (real_id);
 	break;
     case Resources::RESOURCE_FORM:
-	Resources::Form *form = new Resources::Form (id);
+	Resources::Form *form = new Resources::Form (real_id);
 	form->widget_changed.connect (SigC::slot (&ResourceManager::resource_changed_cb));
 	res = form;
 	break;
     }
     
-    resource_map.insert (pair<string_case, Resources::Resource*> (id, res));
+    resource_map.insert (pair<string_case, Resources::Resource*> (real_id, res));
 
     res->changed.connect (SigC::slot (&ResourceManager::resource_changed_cb));
 
