@@ -1,4 +1,4 @@
-//$Id: resource-manager.h,v 1.6 2001/04/02 22:46:38 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.h,v 1.7 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -28,6 +28,7 @@ namespace Guikachu
 #include "resource.h"
 #include "app-res.h"
 #include "string-case.h"
+#include "storage-node.h"
 #include <map>
 #include <set>
 #include <sigc++/signal_system.h>
@@ -69,8 +70,7 @@ namespace Guikachu
 
     private:
 	static void resource_changed_cb ();
-	static Resources::Resource* load_resource (xmlDocPtr doc,
-						   xmlNodePtr node);
+	static Resources::Resource* load_resource (StorageNode &node);
     };
 }
 
