@@ -1,4 +1,4 @@
-//$Id: resource.h,v 1.11 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
+//$Id: resource.h,v 1.12 2001/09/16 13:06:06 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,6 +41,7 @@ namespace Guikachu
 }
 
 #include "property.h"
+#include "storage-node.h"
 #include "resource-manager.h"
 
 namespace Guikachu
@@ -68,8 +69,8 @@ namespace Guikachu
 	    
 	private:
 	    // Persistance
-	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node) = 0;
-	    virtual void save (xmlNodePtr node) const = 0;
+	    virtual bool load (StorageNode &node) = 0;
+	    virtual void save (StorageNode &node) const = 0;
 	    virtual void save_rcp (ostream &ostr) const = 0;
 	    friend ostream& operator<< (ostream &ostr, const Resource *res);
 
