@@ -1,4 +1,4 @@
-//$Id: resource-combo.cc,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: resource-combo.cc,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -26,16 +26,13 @@
 
 using namespace Guikachu;
 
-GUI::ResourceCombo::ResourceCombo (Resources::Type type_,
-				   SigC::Slot0<string> get_slot,
-				   const SigC::Slot1<void, const string&> set_slot,
-				   SigC::Signal0<void>& changed):
+GUI::ResourceCombo::ResourceCombo (Resources::Type   type_,
+				   Property<string> &property_):
     Gtk::HBox (false, 5),
     button_edit (_("Edit...")),
     type (type_),
     current (""),
-    get_val (get_slot),
-    set_val (set_slot)
+    property (property_)
 {
     combo.set_value_in_list (true, true);
     combo.set_use_arrows (true);
@@ -60,8 +57,8 @@ GUI::ResourceCombo::ResourceCombo (Resources::Type type_,
     
     pack_start (combo);
     pack_start (button_edit);
-
-    changed.connect (slot (this, &ResourceCombo::update));
+    
+    property.changed.connect (slot (this, &ResourceCombo::update));
     update ();
 }
 
@@ -72,12 +69,12 @@ void GUI::ResourceCombo::add_resource (Resources::Resource *res)
 
     update_block = true;
 
-    Gtk::ListItem *item = new Gtk::ListItem (res->get_id ());
+    Gtk::ListItem *item = new Gtk::ListItem (res->id);
     item->set_user_data (res);
     item->show ();
     combo.get_list ()->add (*manage (item));
 
-    if (res->get_id () == current)
+    if (res->id == current)
 	current_res = res;
     combo.get_entry ()->set_text (current);
 
@@ -104,15 +101,15 @@ void GUI::ResourceCombo::remove_resource (Resources::Resource *res)
 
     update_block = false;
 
-    if (res->get_id () == current)
-	set_val ("");
+    if (res->id == current)
+	property = "";
 }
 
 void GUI::ResourceCombo::update ()
 {
     update_block = true;
 
-    current = get_val ();
+    current = property;
     current_res = ResourceManager::get_resource (current);
     
     combo.get_entry ()->set_text (current);
@@ -131,10 +128,7 @@ void GUI::ResourceCombo::edit_cb ()
 void GUI::ResourceCombo::entry_cb ()
 {
     if (!update_block)
-    {
-	current = combo.get_entry ()->get_text ();
-	set_val (current);
-    }
+	property = combo.get_entry ()->get_text ();
     
     if (current != "")
 	button_edit.set_sensitive (true);
@@ -145,7 +139,7 @@ void GUI::ResourceCombo::entry_cb ()
 void GUI::ResourceCombo::resource_changed_cb (Resources::Resource *res)
 {
     if (res == current_res)
-	combo.get_entry ()->set_text (res->get_id ());
+	combo.get_entry ()->set_text (res->id);
     
     update_block = true;
 
@@ -158,7 +152,7 @@ void GUI::ResourceCombo::resource_changed_cb (Resources::Resource *res)
     g_return_if_fail (i != itemlist.end ());
     
     (*i)->remove ();
-    (*i)->add_label (res->get_id ());
+    (*i)->add_label (res->id);
     
     update_block = false;
 }
