@@ -1,4 +1,4 @@
-//$Id: resource-combo.h,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: resource-combo.h,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,6 +30,7 @@ namespace Guikachu
 #include <gtk--/box.h>
 #include <gtk--/combo.h>
 #include <gtk--/button.h>
+#include "property.h"
 #include "resource.h"
 
 namespace Guikachu
@@ -45,13 +46,10 @@ namespace Guikachu
 	    string current;
 	    Resources::Resource *current_res;
 
-	    SigC::Slot0<string> get_val;
-	    SigC::Slot1<void, string> set_val;
+	    Property<string> &property;
 	public:
-	    ResourceCombo (Resources::Type type,
-			   SigC::Slot0<string> get_slot,
-			   SigC::Slot1<void, const string&> set_slot,
-			   SigC::Signal0<void>& changed);
+	    ResourceCombo (Resources::Type   type,
+			   Property<string> &property);
 	private:
 	    bool update_block;
 	    void update ();
